Struct odra_types::ExecutionError
source · [−]pub struct ExecutionError(_, _);Expand description
An error that can occur during smart contract execution
It is represented by an error code and a human-readable message.
Errors codes 0..32767 are available for the user to define custom error in smart contracts. 32768 code is a special code representing a violation of the custom error code space.
The rest of codes 32769..u16::MAX, are used internally by the framework.
Implementations
sourceimpl ExecutionError
impl ExecutionError